@@ -46,13 +46,16 @@ namespace FSpot.UI.Dialog
                     "\tIain Lane",
                     "\tLorenzo Milesi",
                     "\tŁukasz Jernaś",
+                    "\tMartin Slota",
                     "\tMike Gem\x00fcnde",
                     "\tMike Wallick",
                     "\tNick Van Eeckhout",
+                    "\tNuno Ferreira",
                     "\tPaul Lange",
                     "\tPaul Wellner Bou",
                     "\tPeter Goetz",
                     "\tRuben Vermeersch",
+                    "\tTim Howard",
                     "\tTim Retout",
                     "\tTomas Kovacik",
                     "\tTrevor Buchanan",
